pub struct OllamaProvider { /* private fields */ }Expand description
Ollama embedding provider
Generates embeddings via a local Ollama server. Requires Ollama to be running with an embedding model pulled.
Implementations
Sourceimpl OllamaProvider
impl OllamaProvider
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Create a new Ollama provider with the default model (nomic-embed-text)
Sourcepub fn with_model(model: &str) -> Result<Self>
pub fn with_model(model: &str) -> Result<Self>
Create a new Ollama provider with a specific model
Sourcepub fn with_dimensions(model: &str, dims: usize) -> Result<Self>
pub fn with_dimensions(model: &str, dims: usize) -> Result<Self>
Create with custom dimensions (for models not in our known list)