Module executor

Module executor 

Structs

ComponentCache
Cache for compiled components
Skill
Auto-generated bindings for an instance a component which implements the world skill.
SkillExecutor
High-level executor for running skills
SkillIndices
Auto-generated bindings for index of the exports of skill.
SkillPre
Auto-generated bindings for a pre-instantiated version of a component which implements the world skill.