pub struct Skill { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world skill.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
Skill::instantiate_asyncwhich only needs aStore,Component, andLinker. -
Alternatively you can create a
SkillPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesSkillPre::instantiate_asyncto create aSkill. -
If you’ve instantiated the instance yourself already then you can use
Skill::new. -
You can also access the guts of instantiation through
SkillIndices::new_instancefollowed bySkillIndices::loadto crate an instance of this type.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl Skill
impl Skill
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Skill>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Skill>where
_T: Send,
Convenience wrapper around SkillPre::new and
SkillPre::instantiate_async.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Skill>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Skill>
Convenience wrapper around SkillIndices::new_instance and
SkillIndices::load.
pub async fn call_get_metadata<S: AsContextMut>( &self, store: S, ) -> Result<String>
pub async fn call_get_tools<S: AsContextMut>(&self, store: S) -> Result<String>
pub async fn call_execute_tool<S: AsContextMut>( &self, store: S, arg0: &str, arg1: &str, ) -> Result<String>
pub async fn call_validate_config<S: AsContextMut>( &self, store: S, arg0: &str, ) -> Result<String>