pub struct SkillIndices { /* private fields */ }Expand description
Implementations
Sourceimpl SkillIndices
impl SkillIndices
Sourcepub fn new(component: &Component) -> Result<Self>
pub fn new(component: &Component) -> Result<Self>
Creates a new copy of SkillIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn new_instance(
store: impl AsContextMut,
instance: &Instance,
) -> Result<Self>
pub fn new_instance( store: impl AsContextMut, instance: &Instance, ) -> Result<Self>
Creates a new instance of SkillIndices from an
instantiated component.
This method of creating a Skill will perform string
lookups for all exports when this method is called. This
will only succeed if the provided instance matches the
requirements of Skill.