pub struct CompletionRequest {
pub messages: Vec<ChatMessage>,
pub temperature: Option<f32>,
pub max_tokens: Option<u32>,
pub stop: Option<Vec<String>>,
}Expand description
LLM completion request
Fields
messages: Vec<ChatMessage>Messages for chat completion
temperature: Option<f32>Temperature (0.0-1.0)
max_tokens: Option<u32>Maximum tokens to generate
stop: Option<Vec<String>>Stop sequences
Implementations
Sourceimpl CompletionRequest
impl CompletionRequest
Sourcepub fn new(prompt: impl Into<String>) -> Self
pub fn new(prompt: impl Into<String>) -> Self
Create a new completion request with a single user prompt
Sourcepub fn with_system(system: impl Into<String>, user: impl Into<String>) -> Self
pub fn with_system(system: impl Into<String>, user: impl Into<String>) -> Self
Create a request with system prompt and user message
Sourcepub fn temperature(self, temp: f32) -> Self
pub fn temperature(self, temp: f32) -> Self
Set temperature
Sourcepub fn max_tokens(self, max: u32) -> Self
pub fn max_tokens(self, max: u32) -> Self
Set max tokens