pub struct GitSkillLoader { /* private fields */ }Expand description
Loads skills from Git repositories
Implementations
Sourceimpl GitSkillLoader
impl GitSkillLoader
Sourcepub fn get_repo_dir(&self, source: &GitSource) -> PathBuf
pub fn get_repo_dir(&self, source: &GitSource) -> PathBuf
Get the directory for a cloned repo
Sourcepub async fn clone_skill(
&self,
source: &GitSource,
force: bool,
) -> Result<ClonedSkill>
pub async fn clone_skill( &self, source: &GitSource, force: bool, ) -> Result<ClonedSkill>
Clone or update a Git repository and prepare for loading
Sourcepub async fn build_skill(&self, cloned: &ClonedSkill) -> Result<PathBuf>
pub async fn build_skill(&self, cloned: &ClonedSkill) -> Result<PathBuf>
Build the skill if necessary and return the WASM component path
Sourcepub fn remove_source(&self, source: &GitSource) -> Result<()>
pub fn remove_source(&self, source: &GitSource) -> Result<()>
Remove a cloned repository