Docker Runtime - Execute skills in Docker containers
This module provides the ability to run skills inside Docker containers, enabling use of existing container images as skill backends.
Example Manifest Configuration
[skills.ffmpeg]
source = "docker:jrottenberg/ffmpeg:5-alpine"
runtime = "docker"
[skills.ffmpeg.docker]
image = "jrottenberg/ffmpeg:5-alpine"
entrypoint = "/usr/local/bin/ffmpeg"
volumes = ["${SKILL_WORKDIR}:/workdir"]
working_dir = "/workdir"
memory = "512m"
cpus = "2"
network = "none"
rm = trueStructs
- Docker
Output - Output from Docker container execution
- Docker
Runtime - Docker runtime executor
- Docker
Security Policy - Security constraints for Docker execution